#
# spec file for package libsemanage
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libsemanage
Version:        2.5
Release:        6.3.1
Summary:        SELinux binary policy manipulation library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            https://github.com/SELinuxProject/selinux/wiki/Releases
Source:         https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20160223/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        semanage.conf
Patch0:         suse_path.patch
Patch1:         libsemanage-version-numbers.patch
Patch2:         libsemanage-check-module-dir.patch
BuildRequires:  audit-devel
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libbz2-devel
BuildRequires:  libselinux-devel
BuildRequires:  libsepol-devel
BuildRequires:  libustr-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Security-enhanced Linux is a feature of the Linux kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement, Role-based Access
Control, and Multi-level Security.

libsemanage provides an API for the manipulation of SELinux binary policies.
It is used by checkpolicy (the policy compiler) and similar tools, as well
as by programs like load_policy that need to perform specific transformations
on binary policies such as customizing policy boolean settings.

%package -n libsemanage1
Summary:        SELinux binary policy manipulation library
Group:          System/Libraries

%description -n libsemanage1
Security-enhanced Linux is a feature of the Linux kernel and a
number of utilities with enhanced security functionality designed to
add mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These architectural
components provide general support for the enforcement of many kinds of
mandatory access control policies, including those based on the
concepts of Type Enforcement, Role-based Access Control, and
Multi-level Security.

libsemanage provides an API for the manipulation of SELinux binary
policies. It is used by checkpolicy (the policy compiler) and similar
tools, as well as by programs like load_policy that need to perform
specific transformations on binary policies such as customizing policy
boolean settings.

%package devel
Summary:        Header files and libraries used to build policy manipulation tools
# FIXME: use correct group, see "https://en.opensuse.org/openSUSE:Package_group_guidelines"
Group:          Development/Libraries
Requires:       libsemanage1 = %{version}
Requires:       libustr-devel

%description devel
The semanage-devel package contains the libraries and header files
needed for developing applications that manipulate binary policies.

%package devel-static
Summary:        SELinux binary policy manipulation library
Group:          System/Libraries
Requires:       libsemanage-devel

%description devel-static
The semanage-static package contains the static libraries
needed for developing applications that manipulate binary policies.

%prep
%setup -q
%patch0 -p0
%patch1 -p1
%patch2 -p1

%build
make %{?_smp_mflags} clean
make -j1 CFLAGS="%{optflags}" CC="gcc"
make -j1 CFLAGS="%{optflags}" LIBDIR="%{_libdir}" LIBEXECDIR="%{_libexecdir}" SHLIBDIR="%{_lib}" CC="gcc" all

%install
mkdir -p %{buildroot}/%{_lib}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
make DESTDIR=%{buildroot} LIBDIR="%{buildroot}%{_libdir}" LIBEXECDIR="%{buildroot}%{_libexecdir}" SHLIBDIR="%{buildroot}/%{_lib}" install
ln -sf  %{_libdir}/libsemanage.so.1 %{buildroot}/%{_libdir}/libsemanage.so
cp %{SOURCE2} %{buildroot}%{_sysconfdir}/selinux/semanage.conf
# Remove duplicate files
%fdupes -s %{buildroot}%{_mandir}

%post -n libsemanage1 -p /sbin/ldconfig
%postun -n libsemanage1 -p /sbin/ldconfig

%files -n libsemanage1
%defattr(-,root,root)
%dir %{_sysconfdir}/selinux
%config(noreplace) %{_sysconfdir}/selinux/semanage.conf
%{_libdir}/libsemanage.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libsemanage.so
%{_libdir}/pkgconfig/libsemanage.pc
%dir %{_libexecdir}/selinux
%{_libexecdir}/selinux/semanage_migrate_store
%dir %{_includedir}/semanage
%{_includedir}/semanage/*.h
%{_mandir}/man3/*
%{_mandir}/man5/*

%files devel-static
%defattr(-,root,root)
%{_libdir}/libsemanage.a

%changelog
* Tue Jan 15 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Prevent error message when reading module version if directory
  does not exists [bsc#1115500]
  * Added patch libsemanage-check-module-dir.patch
* Mon Jun 19 2017 jsegitz@suse.com
- Added libsemanage-version-numbers.patch by Petr Lautrbach to show version
  numbers of modules where they are available (bsc#1043237)
* Fri May 19 2017 jsegitz@suse.com
- Limit to policy version 29 to help fix bsc#1038189
* Thu Jul 14 2016 jsegitz@novell.com
- Without bug number no submit to SLE 12 SP2 is possible, so to make
  sle-changelog-checker happy: bsc#988977
* Wed Jul 13 2016 jsegitz@novell.com
- Added suse_path.patch to fix path to hll compiler
* Fri Jul  8 2016 i@marguerite.su
- update version 2.5
  * Do not overwrite CFLAGS in test Makefile, from Nicolas Iooss.
  * Fix uninitialized variable in direct_commit and direct_api
  * semanage_migrate_store: Load libsepol.so.1 instead of libsepol.so
  * Store homedir_template and users_extra in policy store
  * Fix null pointer dereference in semanage_module_key_destroy
  * Add semanage_module_extract() to extract a module as CIL or HLL
  * semanage_migrate_store: add -r <root> option for migrating inside chroots
  * Add file_contexts and seusers to the store
  * Add policy binary and file_contexts.local to the store
  * Allow to install compressed modules without a compression extension
  * Do not copy contexts in semanage_migrate_store
  * Fix logic in bunzip for uncompressed pp files
  * Fix fname[] initialization in test_utilities.c
  * Add remove-hll semanage.conf option to remove HLL files after
  compilation to CIL
  * Fix memory leaks when parsing semanage.conf
  * Change bunzip to use heap instead of stack to prevent segfault on
  systems with small stack size
- changes in 2.4
  * Fix Makefile to allow LIBDIR and SHLIBDIR to be set to different
  directories
  * Fix bugs found by hardened gcc flags
  * Add missing manpage links to security_load_policy
  * Fix failing libsemanage pywrap tests
  * Fix deprecation warning for bison
  * Skip policy module relink when only setting booleans
  * Only try to compile file contexts if they exist
  * Fix memory leak when setting a custom store path
  * Add semodule option to set store root path in semanage.conf and the
  semodule command
  * Add semanage.conf option to set an alternative root path for policy
  store
  * Add support for High Level Language (HLL) to CIL compilers. The HLL
  compiler path is configurable, but should be placed in
  /usr/libexec/selinux/hll by default
  * Create a policy migration script for migrating the policy store from
  /etc/selinux to /var/lib/selinux
  * Add python3 support to the migration script
  * Use libcil to compile modules
  * Use symbolic versioning to maintain ABI compatibility for old install
  functions
  * Add a target-platform option to semanage.conf to control how policies
  are built
  * Add API to handle modules and source policies, moving module store to
  /var/lib/selinux
  * Only try to compile file contexts if they exist
* Sun May 18 2014 crrodriguez@opensuse.org
- version 2.3
  * Fix memory leak in semanage_genhomedircon from Thomas Hurd.
* Tue Feb 11 2014 vcizek@suse.com
- add semanage.conf as SOURCE and install it instead of the default
  one
* Thu Oct 31 2013 p.drouand@gmail.com
- Update to version 2.2
  * Avoid duplicate list entries
  * Add audit support to libsemanage
  * Remove policy.kern and replace with symlink
  * Apply a MAX_UID check for genhomedircon
  * Fix man pages
- Add audit-devel BuildRequires; new dependency
- Add fdupes BuildRequires and use it to symlink duplicate manpages
* Thu Jun 27 2013 vcizek@suse.com
- change the source url to the official 2.1.10 release tarball
* Thu Apr  4 2013 vcizek@suse.com
- fixed source url
- removed old tarball
* Fri Mar 29 2013 vcizek@suse.com
- update to 2.1.10
  * Add sefcontext_compile to compile regex everytime policy is rebuilt
  * Cleanup/fix enable/disable/remove module.
  * redo genhomedircon minuid
  * fixes from coverity
  * semanage_store: do not leak memory in semanage_exec_prog
  * genhomedircon: remove useless conditional in get_home_dirs
  * genhomedircon: double free in get_home_dirs
  * fcontext_record: do not leak on error in semanage_fcontext_key_create
  * genhomedircon: do not leak on failure in write_gen_home_dir_context
  * semanage_store: do not leak fd
  * genhomedircon: do not leak shells list
  * semanage_store: do not leak on strdup failure
  * semanage_store: rewrite for readability
* Wed Jan 30 2013 vcizek@suse.com
- update to 2.1.9
  * dropped libsemanage-2.1.6-NULL_level_fix.patch (fixed upstream)
  * libsemanage: do not set soname needlessly
  * libsemanage: remove PYTHONLIBDIR and ruby equivalent
  * do boolean name substitution
  * Fix segfault for building standard policies.
  * remove build warning when build swig c files
  * additional makefile support for rubywrap
  * ignore 80 column limit for readability
  * semanage_store: fix snprintf length argument by using asprintf
  * Use default semanage.conf as a fallback
  * use after free in python bindings
  * Alternate path for semanage.conf
  * do not link against libpython, this is considered bad in Debian
  * Allow to build for several ruby version
  * fallback-user-level
* Mon Jan  7 2013 jengelh@inai.de
- Remove obsolete defines/sections
* Wed Oct 24 2012 vcizek@suse.com
- when building "standard" (not MCS/MLS) selinux-policies,
  libsemanage will crash, because "level" is NULL
  (libsemanage-2.1.6-NULL_level_fix.patch)
* Mon Aug 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+
  Could not find any LGPL-2.1 "only" licensed files in the pacakge
* Wed Aug  1 2012 meissner@suse.com
- Updated to 2.1.6
  * changes too numerous to list
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Sep 22 2011 dmueller@suse.de
- buildrequire libbz2-devel
* Mon May 23 2011 prusnak@opensuse.org
- split off python bindings to separate package to reduce build
  dependencies for rpm [bnc#695436]
* Wed May 18 2011 coolo@novell.com
- add baselibs.conf for rpm-32bit to use
* Wed Feb 23 2011 coolo@novell.com
- disable parallel build, it breaks too often
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 2.0.43
  * changes too numerous to list
* Fri Jan 16 2009 prusnak@suse.cz
- fix assignment of wrong context [bnc#466793]
* Wed Jan 14 2009 prusnak@suse.cz
- updated to 2.0.31
  * policy module compression (bzip) support from Dan Walsh
  * hard link files between tmp/active/previous from Dan Walsh
  * add semanage_mls_enabled() interface from Stephen Smalley
* Mon Dec  1 2008 prusnak@suse.cz
- updated to 2.0.29
  * add USER to lines to homedir_template context file
  * add compression support
  * allow fcontext and seuser changes without rebuilding the policy
  * don't rebuild on fcontext or seuser modifications
  * modify genhomedircon to skip %%groupname entries
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Tue Sep 23 2008 prusnak@suse.cz
- require only version, not release [bnc#429053]
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 2.0.27
  * Modify genhomedircon to skip %%groupname entries.
    Ultimately we need to expand them to the list of users to support
    per-role homedir labeling when using the %%groupname syntax.
- updated to 2.0.26
  * Fix bug in genhomedircon fcontext matches logic from Dan Walsh.
    Strip any trailing slash before appending /*$.
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Tue Jul 15 2008 prusnak@suse.cz
-  initial version 2.0.25
  * based on Fedora package by Dan Walsh <dwalsh@redhat.com>
